import { createRouter, createWebHistory } from 'vue-router'
import type { menu } from '@/types/Tool'

import SkeletonPage from '@/views/SkeletonPage.vue'

const router = createRouter({
  history: createWebHistory(import.meta.env.BASE_URL),
  routes: [
    {
      path: '/login',
      name: 'login',
      component: () => import('@/views/LoginPage.vue'),
    },
    {
      path: '/authorized',
      name: 'Authorized',
      component: SkeletonPage,
      children: [
        {
          path: 'adlist',
          name: 'AdList',
          component: () => import('../views/AdListPage.vue'),
        },
        {
          path: 'originality',
          name: 'Originality',
          component: () => import('../views/OriginalityPage.vue'),
        },
        {
          path: 'advertiser',
          name: 'Advertiser',
          component: () => import('../views/AdvertiserPage.vue'),
        },
        {
          path: 'sourceMaterial',
          name: 'SourceMaterial',
          component: () => import('../views/SourceMaterialPage.vue'),
        },
        {
          path: 'site',
          name: 'Site',
          component: () => import('../views/SitePage.vue'),
        },
        {
          path: 'advertisingSpace',
          name: 'AdvertisingSpace',
          component: () => import('../views/AdvertisingSpacePage.vue'),
        },
        {
          path: 'advertisingSpaceDate',
          name: 'AdvertisingSpaceDate',
          component: () => import('../views/AdvertisingSpaceDatePage.vue'),
        },
        {
          path: 'reportForms',
          name: 'ReportForms',
          component: () => import('../views/ReportFormsPage.vue'),
        },
        {
          path: 'reportFormsMonth',
          name: 'ReportFormsMonth',
          component: () => import('../views/ReportFormsMonthPage.vue'),
        },
        {
          path: 'reportSpaceForms',
          name: 'ReportSpaceForms',
          component: () => import('../views/ReportSpaceFormsPage.vue'),
        },
        {
          path: 'reportSpaceFormsMonth',
          name: 'ReportSpaceFormsMonth',
          component: () => import('../views/ReportSpaceFormsMonthPage.vue'),
        },
        {
          path: 'examine',
          name: 'Examine',
          component: () => import('../views/ExaminePage.vue'),
        },
      ],
    },
  ],
})

const checkAuth = (list: menu[], path: string): menu => {
  let out: menu = {}
  for (let i = 0; i < list.length; i++) {
    const v = list[i]
    if (v.children) {
      out = checkAuth(v.children, path)
      if (out.path) break
    } else if (v.path === path) {
      out = v
      break
    }
  }
  return out
}

// 路由卫士
router.beforeEach((to, from, next) => {
  // 如果是登录页面，直接放行
  if (to.path === '/login') return next()
  const token = localStorage.getItem('token')
  const {
    role: { menus },
  }: { role: { menus: menu[] } } = localStorage.getItem('user')
    ? JSON.parse(localStorage.getItem('user') || '')
    : { role: { menus: [] } }
  const haveAuth = checkAuth(menus, to.path)
  if (!token || !haveAuth.path) {
    localStorage.removeItem('phone')
    localStorage.removeItem('token')
    localStorage.removeItem('user')
    return next('/login')
  }
  if (to.path === '/') return next(token ? haveAuth.path : '/login')
  next()
})

export default router
